# NOT RUN {
# Testing the function rolwincor_heatmap
# typewidthwin="PARTIAL," window lengths from 11 to 101 and plot output in screen format
# Code used to produce the outputs to generate the Fig. 4 in Polanco-Mart<U+00ED>nez (2020).
test_rolwincor_heatmap <- rolwincor_heatmap(syntDATA, varX="X", varY="Y",
CorMethod="spearman", typewidthwin="PARTIAL", widthwin_1=11,
widthwin_N=101, Align="center", pvalcorectmethod="BH",
rmltrd=TRUE, Scale=TRUE)
# This example could takes a long time since typewidthwin="FULL"
test2_rolwincor_heatmap <- rolwincor_heatmap(syntDATA, varX="X", varY="Y",
CorMethod="spearman", typewidthwin="FULL", Align="center",
pvalcorectmethod="BH", rmltrd=TRUE, Scale=TRUE)
# }
Run the code above in your browser using DataLab